==> pfacter-1.10-1.tar.gz: pfacter-1.10-1/lib/Pfacter/processor.pm <==
package Pfacter::processor;

sub pfact {
    my $self  = shift;
    my ( $p ) = shift->{'pfact'};

    for ( $p->{'kernel'} ) {
        /AIX/ && do {
            if ( -e '/usr/sbin/lsattr' ) {
                open( F, '/usr/sbin/lsattr -El proc0 |' );
            }
            else {
                return qq((kernel not supported));
            }

            my ( @F ) = <F>;

            close( F );

            my ( $n ) = 0;

            foreach ( @F ) {
                if ( /type\s+(.+?)\s/ ) { $n = $1; last; }
            }

            $n =~ s/\s+$//;

            return $n;
        };

        /Darwin/ && do {
            if ( -e '/usr/bin/hostinfo' ) {
                open( F, '/usr/bin/hostinfo |' );
                my ( @F )  = <F>;
                close( F );

                foreach ( @F ) {
                    return $1 if /Processor\stype:\s(.*)/;
                }
            }
        };

        /Linux/ && do {
            my ( $c ) = 0;

            open( F, '/proc/cpuinfo' );
            my ( @F ) = <F>;
            close( F );

            foreach ( @F ) { $c = $1 if /model name\s+:\s+(.+?)$/; }

            $c =~ s/\s+$//;

            return $c;
        };

        /SunOS/ && do {
            if ( -e '/usr/sbin/prtdiag' ) {
                open( F, '/usr/sbin/prtdiag |' );
                my ( @F ) = <F>;
                close( F );

                foreach ( @F ) {
                    return $1 if /SUNW,(.+?)\s+\d+/;
                }
            }
        };

        return qq((kernel not supported));
    }
}

1;

==> pfacter-1.13-1.tar.gz: pfacter-1.13-1/lib/Pfacter/processor.pm <==
package Pfacter::processor;

#

sub pfact {
    my $self  = shift;
    my ( $p ) = shift->{'pfact'};

    my ( $r );

    for ( $p->{'kernel'} ) {
        /AIX/ && do {
            if ( -e '/usr/sbin/lsattr' ) {
                open( F, '/usr/sbin/lsattr -El proc0 |' );
                my ( @F ) = <F>;
                close( F );

                foreach ( @F ) { if ( /type\s+(.+?)\s/ ) { $r = $1; last; } }

                $r =~ s/\s+$//;
            }
        };

        /Darwin/ && do {
            if ( -e '/usr/bin/hostinfo' ) {
                open( F, '/usr/bin/hostinfo |' );
                my ( @F )  = <F>;
                close( F );

                foreach ( @F ) {
                    if ( /Processor\stype:\s(.*)/ ) { $r = $1; last; }
                }
            }
        };

        /Linux/ && do {
            if ( -e '/proc/cpuinfo' ) {
                open( F, '/proc/cpuinfo' );
                my ( @F ) = <F>;
                close( F );

                foreach ( @F ) {
                    if ( /model name\s+:\s+(.+?)$/ ) { $r = $1; last; }
                }

                $r =~ s/\s+$//;
            }
        };

        /SunOS/ && do {
            if ( -e '/usr/sbin/prtdiag' ) {
                open( F, '/usr/sbin/prtdiag |' );
                my ( @F ) = <F>;
                close( F );

                foreach ( @F ) {
                    if ( /SUNW,(.+?)\s+\d+/ ) { $r = $1; last; }
                }
            }
        };

        if ( $r ) { return( $r ); }
        else      { return( 0 ); }
    }
}

1;
